/**
 * Common types, utility functions.
 * @module data/common
 */
/** Validation rule object: rule string and custom error prompt */
export type RuleObj = {
    type: string;
    prompt?: string;
};
/** Rule definition takes array or single instance of string or RuleObj */
export type RuleDefinition = string | string[] | RuleObj | RuleObj[];
/** Settings controlling number, money, and list formatting. */
export interface NumberSettings {
    decimalSeparator: string;
    thousandSeparator: string;
    moneyPrefix: string;
    moneySuffix: string;
    moneyPrecision: number;
}
/** Settings used to initialize a number input component. */
export interface NumberInputSettings extends Partial<NumberSettings> {
    type?: "integer" | "decimal" | "money";
    precision?: number;
}
export type TextInputSettings = {
    case?: "upper" | "lower" | "title" | "none";
    charset?: "any" | "euro" | "latin" | "ascii" | "id_alpha" | "id_hex" | "id_num";
    idAllowChars?: Array<"_" | "-" | ".">;
    idBlockChars?: Array<"I" | "O" | "i" | "o" | "l">;
    blockSingleQuotes?: boolean;
    blockDoubleQuotes?: boolean;
    allowHtmlTags?: boolean;
    blockEmoji?: boolean;
    /** Maximum value length. Intended for "id_*" charset, in other cases it is often better to use validation */
    maxLen?: number;
    /** The input returns string[] */
    list?: boolean;
    /** Character user to separate values */
    listSeparator?: string;
};
/** Compare two Date objects */
export declare function equalDates(a1: Date | undefined, a2: Date | undefined): boolean;
/** Compare two string arrays or strings */
export declare function equalStringArrays(a1: string[] | string | undefined, a2: string[] | string | undefined): boolean;
/** Compare two number arrays or numbers */
export declare function equalNumberArrays(a1: number[] | number | undefined, a2: number[] | number | undefined): boolean;
/** Format a number, padded with "0" to the minimum length */
export declare function pad(n: number, size: number): string;
/** Format Date using YYYY-MM-DD format */
export declare function isoDate(d: Date | undefined): string;
/** Format Date as time using HH:mm format (24 hours) */
export declare function isoTime(d: Date | undefined): string;
