/**
 * Common types, utility functions.
 * @module data/common
 */
// /** Semantic UI component behavior API */
// export type SemanticCommand = (
//     command: string,
//     v1?: unknown,
//     v2?: unknown,
//     v3?: unknown
// ) => unknown;
// /** Return type for a simple svelte action; with destroy(), but without update(). */
// export type ActionReturnType = {
//     destroy: () => void;
// } | void;
//-----------------------------------------------------------------------------
/*
            dP   oo dP
            88      88
 dP    dP d8888P dP 88
 88    88   88   88 88
 88.  .88   88   88 88
 `88888P'   dP   dP dP

*/
/** Compare two Date objects */
export function equalDates(a1, a2) {
    if (a1 instanceof Date && a2 instanceof Date) {
        return a1.getTime() === a2.getTime();
    }
    return a1 === a2;
}
/** Compare two string arrays or strings */
export function equalStringArrays(a1, a2) {
    if (Array.isArray(a1) && Array.isArray(a2)) {
        if (a1.length !== a2.length) {
            return false;
        }
        for (let i = 0; i < a1.length; i++) {
            if (a1[i] !== a2[i]) {
                return false;
            }
        }
        return true;
    }
    return a1 === a2;
}
/** Compare two number arrays or numbers */
export function equalNumberArrays(a1, a2) {
    if (Array.isArray(a1) && Array.isArray(a2)) {
        if (a1.length !== a2.length) {
            return false;
        }
        for (let i = 0; i < a1.length; i++) {
            if (a1[i] !== a2[i]) {
                return false;
            }
        }
        return true;
    }
    return a1 === a2;
}
/** Format a number, padded with "0" to the minimum length */
export function pad(n, size) {
    let str = n.toString();
    while (str.length < size) {
        str = `0${str}`;
    }
    return str;
}
/** Format Date using YYYY-MM-DD format */
export function isoDate(d) {
    if (!d || !d.getDate) {
        return "";
    }
    const day = pad(d.getDate(), 2);
    const month = pad(d.getMonth() + 1, 2);
    const year = pad(d.getFullYear(), 4);
    return `${year}-${month}-${day}`;
}
/** Format Date as time using HH:mm format (24 hours) */
export function isoTime(d) {
    if (!d || !d.getDate) {
        return "";
    }
    const hour = pad(d.getHours(), 2);
    const minute = pad(d.getMinutes(), 2);
    return `${hour}:${minute}`;
}
